@@ -206,7 +206,6 @@ create table "public"."t_flink_app" (
   "options" text collate "pg_catalog"."default",
   "hot_params" text collate "pg_catalog"."default",
   "user_id" int8,
-  "app_id" varchar(64) collate "pg_catalog"."default",
   "app_type" int2,
   "duration" int8,
   "job_id" varchar(64) collate "pg_catalog"."default",
@@ -422,7 +421,7 @@ create table "public"."t_flink_project" (
   "team_id" int8,
   "name" varchar(255) collate "pg_catalog"."default",
   "url" varchar(255) collate "pg_catalog"."default",
-  "branches" varchar(64) collate "pg_catalog"."default",
+  "refs" varchar(64) collate "pg_catalog"."default",
   "user_name" varchar(64) collate "pg_catalog"."default",
   "password" varchar(64) collate "pg_catalog"."default",
   "prvkey_path" varchar(128) collate "pg_catalog"."default",
@@ -739,7 +738,7 @@ create table "public"."t_external_link" (
   "badge_label" varchar(64) collate "pg_catalog"."default",
   "badge_name" varchar(64) collate "pg_catalog"."default",
   "badge_color" varchar(64) collate "pg_catalog"."default",
-  "link_url" varchar(255) collate "pg_catalog"."default",
+  "link_url" text collate "pg_catalog"."default",
   "create_time" timestamp(6),
   "modify_time" timestamp(6))
 ;
